/*
 * A demonstration of bitmap plotting.
 *
 * Copyright (C) 2013 Paul Boddie
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 */

#include "pcf8833.h"
#include <stdio.h>
#include <unistd.h>
#include <signal.h>
#include <stdlib.h>
#include "bitmaps.h"

/**
 * Handle termination of the process.
 */
void shutdown(int signum)
{
    printf("Closing...\n");
    ubb_close(0);
    exit(1);
}

void lcd_shutdown(int signum)
{
    LCD_off();
    shutdown(signum);
}

void bitmap(uint8_t image)
{
    LCD_image(0, 0, image_data[image], IMAGE_WIDTH, IMAGE_HEIGHT);
}

uint8_t states[] = {LCD_MADCTL_MY_MX, LCD_MADCTL_MY_V, 0, LCD_MADCTL_MX_V};

int main(int argc, char *argv[])
{
    uint8_t state = 1;
    uint8_t times;
    uint8_t current_image = 0;

    signal(SIGINT, shutdown);

    /* Access the 8:10 port. */

    if (ubb_open(0) < 0) {
        perror("ubb_open");
        return 1;
    }

    ubb_power(1);
    printf("Power on.\n");

    spi_init();
    LCD_init();

    signal(SIGINT, lcd_shutdown);

    bitmap(current_image);

    while (times--)
    {
        sleep(1);
        printf("Updating...\n");

        LCD_send(LCD_COMMAND, LCD_MADCTL);
        LCD_send(LCD_DATA, states[state]);
        bitmap(current_image);

        state = (state + 1) % 4;
        current_image = (current_image + 1) % NUMBER_OF_IMAGES;
    }

    LCD_off();

    printf("Closing...\n");
    ubb_close(0);
    return 0;
}

/* vim: tabstop=4 expandtab shiftwidth=4
 */
